using System;
using System.Data.SqlClient;
using System.Diagnostics;
using Vha.Vss.Utility;

namespace Vha.Vss.Utility
{
  /// <summary>
  /// VhaLogType represents the type of log information item represents.
  /// </summary>
  public enum VhaLogType
  {
    /// <summary>Information</summary>
    Information  = EventLogEntryType.Information,
    /// <summary>Warning</summary>
    Warning      = EventLogEntryType.Warning,
    /// <summary>Error</summary>
    Error        = EventLogEntryType.Error,
    /// <summary>FailureAudit</summary>
    FailureAudit = EventLogEntryType.FailureAudit,
    /// <summary>SuccessAudit</summary>
    SuccessAudit = EventLogEntryType.SuccessAudit,
  };

  /// <summary>
  /// WriteLogEntry is an Event Delegate.
  /// </summary>
  public delegate void WriteLogEntry(string sourceName, int code, VhaLogType type, string message, int category);

  /// <summary>
  ///    Class that handles all of the writing of logging information
  /// </summary>
  public class VhaLog
  {    
		public VhaLog(){}
		/// <summary>
		/// 
		/// </summary>
		/// <param name="sSource"></param>
		/// <param name="sLog"></param>
		/// <param name="sEvent"></param>
		public static void WriteLog(string Source, string Log, string Event)
		{
			if (!EventLog.SourceExists(Source))
				EventLog.CreateEventSource(Source,Log);

			EventLog.WriteEntry(Source,Event);
			EventLog.WriteEntry(Source, Event,
				EventLogEntryType.Warning, 234);
		}
		public static void WriteLog(string Source, string Log, string Event, EventLogEntryType EntryType)
		{
			if (!EventLog.SourceExists(Source))
				EventLog.CreateEventSource(Source,Log);
			
			
			EventLog.WriteEntry(Source,Event);
			EventLog.WriteEntry(Source, Event, EntryType, 234);
		}
		
		/// <summary>
		/// Walks the exception chain and builds a detail hierarchy
		/// </summary>
		///<Params>
		/// <param type="Exception" name="e">Exception to unwind</param>
		///</Params>
		///<returns type="string">
		///Returns the string details of the exception tree
		///</returns>
		public static string BuildExceptionDetails(Exception e)
		{
			string strDetails = "";
      
			strDetails += "Exception Type: " + e.GetType().ToString();

			if (e is SqlException)
			{
				SqlException eSQL = (SqlException)e;
				SqlError sqlError;
				int nI = 0;

				strDetails += String.Format("\r\n Errors.Count = {0}", eSQL.Errors.Count );
				foreach (SqlError sqlE in eSQL.Errors)
				{
					nI++;

					strDetails += String.Format("\r\n ********** Error #{0} *********", nI );
					strDetails += "\r\n ->Class: " + sqlE.Class;
					strDetails += "\r\n ->Number: " + sqlE.Number;
					strDetails += "\r\n ->Server: " + sqlE.Server;
					strDetails += "\r\n ->Source: " + sqlE.Source;
					strDetails += "\r\n ->Procedure: " + sqlE.Procedure;
					strDetails += "\r\n ->LineNumber: " + sqlE.LineNumber;
					strDetails += "\r\n ->State: " + sqlE.State;
					strDetails += "\r\n ->Message: " + sqlE.Message;
				}
			}

			strDetails += "\r\nException Message: " + e.Message;
			strDetails += "\r\n\r\nSource: " + e.Source;
			strDetails += "\r\nSite: " + e.TargetSite;
			strDetails += "\r\nStackTrace: " + e.StackTrace + "\r\n";

			if (e.InnerException != null)
				strDetails += "\r\n************* Inner Exception **********************\r\n" + BuildExceptionDetails(e.InnerException);

			return strDetails;
		}
  } // class ConsoleLogWriter

} // namespace Vha.Vha.Utility

