using System;
using System.Xml;

namespace Vha.Vss.Security
{
  /// <summary>
  /// eSupportSecurityException extends System.ApplicationException by adding an additional
  /// property called Errors to the class.  These exceptions are thrown by the 
  /// AppSecurityGroups and SecurityGroup classes in order to provide additional
  /// error information from the database transaction to the calling application.
  /// </summary>
  public class VhaSecurityException : System.ApplicationException
  {
    /// <summary>
    /// Default "See Errors Information" Tag
    /// </summary>
    public const String tag = "\nSee Errors property for extended error information.\n";
    private XmlNode m_Errors=null;
    /// <summary>
    /// Default constructor.
    /// </summary>
    public VhaSecurityException() : base() 
    { 
    }
    /// <summary>
    /// Constructor that initializes the Message property of the base class object.
    /// </summary>
    /// <Params>
    /// <param name="message">Message to be carried in the exception.
    /// </param>
    /// </Params>
    public VhaSecurityException(String message) : base(message) 
    { 
    }
    /// <summary>
    /// Constructor that initializes the Message and innerException properties of the base class object.
    /// </summary>
    /// <Params>
    /// <param name="message">Message to be carried in the exception.</param>
    /// <param name="innerException">Additional exception information that can be optionally reported by the error page.</param>
    /// </Params>
    public VhaSecurityException(String message, Exception innerException) : base(message, innerException) 
    {
    }
    /// <summary>
    /// Constructor that initializes the Message property of the base class object
    /// and the CorrectiveAction property of the derived class.  This is the most 
    /// commonly used constructor.
    /// </summary>
    /// <Params>
    /// <param name="message" type="String" >Message to be carried in the exception.</param>
    /// <param name="errors" type="XmlNode" >
    /// Standard eSupport errors structure as defined in the Tier 2 design document.
    /// </param>
    /// </Params>
    public VhaSecurityException(String message, XmlNode errors) : base(message+tag) 
    { 
      m_Errors = errors;
    }
    /// <summary>
    /// Constructor that initializes the Message property of the base class object
    /// and the CorrectiveAction property of the derived class.  This is the most 
    /// commonly used constructor.
    /// </summary>
    /// <Params>
    /// <param name="message">Message to be carried in the exception.</param>
    /// <param name="innerException">Additional exception information that can be optionally reported by the error page.</param>
    /// <param name="errors" type="XmlNode" >
    /// Standard VHA errors structure.
    /// </param>
    /// </Params>
    public VhaSecurityException(String message, Exception innerException, XmlNode errors) : base(message+tag, innerException) 
    {
      m_Errors = errors;
    }
    /// <summary>
    /// Standard eSupport errors structure as defined in the Tier 2 design document.
    /// </summary>
    public XmlNode Errors
    {
      get { return m_Errors; }
      set { m_Errors = value; }
    }
  } // end class
} // end namespace