using System;
using System.Text;
using System.Reflection;
using System.Configuration;

namespace Vha.Vtk.DataClasses
{
	/// <summary>
	/// The ErrorHandle.ErrorHandler Method is used to throw a VhaMsSqlServerSaveException
	/// when an error occurs in Inserting, Updating, or Deleting an entry.  Data from the
	/// Vha.Vtk.DataClasses.Parameters.SqlException is used to populate the error.
	/// 
	/// To use this first add to your using statement:
	///		using spErr = Vha.Vtk.DataClasses.ErrorHandler
	///		
	///	Then in your code it can be used similarly to
	///		if (!spSProc.Execute(ref spParam))
	///		{
	///			spErr.ErrorHandler("User", "Delete", spParam);
	///		}
	/// </summary>
	public class ErrorHandle
	{
		/// <summary>
		/// The ErrorHandle.ErrorHandler Method is used to throw a VhaMsSqlServerSaveException
		/// when an error occurs in Inserting, Updating, or Deleting an entry.  Data from the
		/// Vha.Vtk.DataClasses.Parameters.SqlException is used to populate the error.
		/// 
		/// To use this first add to your using statement:
		///		using spErr = Vha.Vtk.DataClasses.ErrorHandler
		///		
		///	Then in your code it can be used similarly to
		///		if (!spSProc.Execute(ref spParam))
		///		{
		///			spErr.ErrorHandler("User", "Delete", spParam);
		///		}
		/// </summary>
		/// <param name="className">name of the class that error was thrown in</param>
		/// <param name="transactionType">Type of transaction (Insert, Update, or Delete)</param>
		/// <param name= "ie">Error Information</param>
		public static void ErrorHandler(string className, string  transactionType, IErrorInformation ie)
		{
			//debugging variables...
			string errorSource     = ie.ErrorSource.ToString();	
			string message         = ie.SqlException.ToString();
			string storedProcedure = ie.StoredProcedureName;

			VhaMsSqlServerSaveException excp = new VhaMsSqlServerSaveException( ie.SqlException.ToString(), 
				className, 
				transactionType,
				ie.StoredProcedureName,
				ie.ErrorSource.ToString());
			throw excp;
		}
	}

	/// <summary>
	/// The VhaMsSqlServerSaveException is populated based on the Error
	/// </summary>
	public class VhaMsSqlServerSaveException: Exception
	{
		#region Section: Processing Fields

		private string className;
		private string errorSource;
		private string transactionType;
		private string storedProcedureName;

		#endregion

		#region Section: Property Definitions

		/// <summary>
		/// ClassName
		/// </summary>
		public string ClassName {get {return className;}
		}

		/// <summary>
		/// Error Source
		/// </summary>
		public string ErrorSource {get {return errorSource;}
		}

		/// <summary>
		/// Transaction Type
		/// </summary>
		public string TransactionType {get {return transactionType;}
		}

		/// <summary>
		/// Stored Procedure Name
		/// </summary>
		public string StoredProcedureName {get {return storedProcedureName;}
		}

		#endregion

	#region Section: Constructors

		/// <summary>
		/// </summary>
		/// <param name="msg"></param>
		/// <param name="className"></param>
		/// <param name="transactionType"></param>
		/// <param name="storedProcedureName"></param>
		/// <param name="errorSource"></param>
		public VhaMsSqlServerSaveException( string msg, 
			string className, 
			string transactionType, 
			string storedProcedureName, 
			string errorSource)        : base(msg)
		{
			this.Source              = className;
			this.className           = className;
			this.errorSource         = errorSource;
			this.transactionType     = transactionType;
			this.storedProcedureName = storedProcedureName;
		}

	#endregion


	}

}
