#region Section: Using Declarations

using System;
using System.Collections;
using System.Data;
using System.Windows.Forms;

#endregion

namespace Vha.Vtk.Kernel.Common
{
	/// <summary>
	/// Exception class used when property validation checks fail during save transactions.
	/// </summary>
	public class VhaValidationException : Exception 
	{
		#region Section: Processing Fields

		/// <summary>
		/// Name of the class that threw the exception.
		/// </summary>
		private string className;

		/// <summary>
		/// Name of the class property that threw the exception.
		/// </summary>
		private string propertyName;

		#endregion
		
		#region Section: Property Definitions

		/// <summary>
		/// Name of the class that threw the exception.
		/// </summary>
		/// <value type="System.String"></value>
		public string ClassName {get {return className;}
		}

		/// <summary>
		/// Name of the class property that threw the exception.
		/// </summary>
		/// <value type="System.String"></value>
		public string PropertyName {get {return propertyName;}
		}

		#endregion
		
		#region Section: Constructors

		/// <summary>
		/// Main constructor
		/// </summary>
		/// <Params>
		/// <param name="msg" type="System.String">Error message</param>
		/// <param name="className" type="System.String">Class name assoicated with exception</param>
		/// <param name="propertyName" type="System.String">Property name assoicated with exception</param>
		/// </Params>
		public VhaValidationException(string msg, string className, string propertyName) : base(msg)
		{
			this.Source       = className + "." + propertyName;
			this.className    = className;
			this.propertyName = propertyName;
		}

		#endregion
	}

	// TODO: Code Enhancement Possibility: (5) Determine if the 'VhaTransactionException' is still needed and used.

	/// <summary>
	/// Exception class used when a save process fails for anything other than validation check errors.
	/// </summary>
	/// <remarks>
	/// <list type="bullet">
	/// <item><description>
	/// This exception maybe obsolete since moving to SQL Server Centric .NET Code Generator.
	/// </description></item>
	/// <item><description>
	/// The exception class defintion remains defined until it is determined it is no longer
	/// needed and the UI team can be notified.
	/// </description></item>
	/// </list>
	/// </remarks>
	public class VhaTransactionException : Exception 
	{
		#region Section: Processing Fields

		/// <summary>
		/// Name of the class that threw the exception.
		/// </summary>
		private string className;

		/// <summary>
		/// Name of the transaction type (insert, update or delete).
		/// </summary>
		private string transactionType;

		#endregion

		#region Section: Property Definitions

		/// <summary>
		/// Name of the class that threw the exception.
		/// </summary>
		/// <value type="System.String"></value>
		public string ClassName {get {return className;}
		}

		/// <summary>
		/// Name of the transaction type (insert, update or delete).
		/// </summary>
		/// <value type="System.String"></value>
		public string TransactionType {get {return transactionType;}
		}


		#endregion

		#region Section: Constructors

		/// <summary>
		/// Main constructor
		/// </summary>
		/// <Params>
		/// <param name="msg" type="System.String">Error message</param>
		/// <param name="className" type="System.String">Class name assoicated with exception</param>
		/// <param name="transactionType" type="System.String">Type of transaction: Insert, update or delete</param>
		/// </Params>
		public VhaTransactionException(string msg, string className, string transactionType) : base(msg)
		{
			this.Source          = className;
			this.className       = className;
			this.transactionType = transactionType;
		}

		#endregion
	}

}
