#region Section: Using Declarations

using System;
using System.Data;

#endregion
namespace Vha.Vtk.Kernel.Common
{
	/// <summary>
	/// Interface that defines methods that must be implemented by any database server layer class. like VolunteerHoursMsSqlSrv.
	/// </summary>
	public interface IDataSrv
	{
		/// <summary>
		/// Releases the resources used by an instance.
		/// </summary>
		/// <returns type="void"></returns>
		void Dispose();

		/// <summary>
		/// Retrieves DataSet for instance based on primary key and associates DataSet with instance.
		/// </summary>
		/// <returns type="void"></returns>
		void GetIdData();

		/// <summary>
		/// Populates instance properties with DataSet data.
		/// </summary>
		/// <returns type="void"></returns>
		void Populate();

		/// <summary>
		/// Populates instance with data from a row produced by a 'SELECT *' statement.
		/// </summary>
		/// <Params>
		/// <param name="dr" type="DataRow">Data row containing data for instance</param>
		/// </Params>
		/// <returns type="void"></returns>
		void Populate(DataRow dr);

		/// <summary>
		/// Sets Dataset, tablename and tablerow properties for instance.
		/// </summary>
		/// <Params>
		/// <param name="ds" type="DataSet">DataSet to assoicate with instance</param>
		/// <param name="tableName" type="System.String">Table name within DataSet to assoicate with instance</param>
		/// <param name="tableRow" type="System.Int">Row number within table to assoicate with instance</param>
		/// </Params>
		/// <returns type="void"></returns>
		void SetDataSetInfo(DataSet ds, string tableName, int tableRow);

		/// <summary>
		/// Inserts new record into database using instance data.
		/// </summary>
		/// <returns type="System.Int">Id number of inserted record</returns>
		int Insert();

		/// <summary>
		/// Updates existing record into database using instance data.
		/// </summary>
		/// <returns type="void"></returns>
		void Update();

		/// <summary>
		/// Deletes existing record from database using instance data.
		/// </summary>
		/// <returns type="void"></returns>
		void Delete();
	}
}
